@@ -1,4 +1,4 @@
-VERSION = (0, 1, 2)
+VERSION = (0, 2, 0)
 __version__ = '.'.join(map(str, VERSION))
 
 
@@ -48,3 +48,13 @@ def get_url(key, language=None):
             cache.set(cache_key, _none_type if url is None else url, 120)
 
     return None if url == _none_type else url
+
+
+def get_forwarding_url(key, language=None):
+    from django.core.urlresolvers import reverse
+    from django.utils.translation import override
+
+    if language is None:
+        return reverse('keyed_url_forward', kwargs={'key': key})
+    with override(language):
+        return reverse('keyed_url_forward', kwargs={'key': key})
