@@ -1,5 +1,6 @@
 from django.conf import settings
 from django.core.cache import cache
+from django.core.urlresolvers import reverse
 from django.db import models
 from django.db.models import signals
 from django.dispatch import receiver
@@ -22,6 +23,9 @@ class KeyedURL(models.Model):
     def get_absolute_url(self):
         return self.url
 
+    def get_forwarding_url(self):
+        return reverse('keyed_url_forward', kwargs={'key': self.key})
+
 
 @receiver(signals.post_save, sender=KeyedURL)
 @receiver(signals.post_delete, sender=KeyedURL)
